/** Michal Korecki I1TIZ
*	
*	Algorytm iota() sluzy do przypisywania arytmetycznie zwiekszajacych
*	sie wartosci do pewnego zadanego przedzialu. Oznacza to, iz przypisuje
*	value do *first, value+1 do *(first+1) itd.. Uogolniajac, każdy iterator i
*	w zadanym przedziale (first,last) ma przypisana wartosc value + (i-first).
*	
*	Iota() algorytm zostal zdefiniowany w standardowym naglowku numeric oraz w 
*	niestandardowym, kompatybilnym wstecz naglowku algo.h. Algorytm ten jest 
*	rozszerzeniem SGI i nie jest on czescia standardu C++.	
*	
*	Parametry:
*	- ForwardIterator first - poczatek zadanego przedzialu, jego pierwszy element
*	- ForwardIterator last - koniec przedzialu, ostatni element
*	- T value - wartosc poczatkowa, ktora sekwencyjnie zwiekszajac bedziemy 
*				przypisywac elementom w zadanym przedziale
*	
*	Prototyp:
*	template <class ForwardIterator, class T>
*	void iota(ForwardIterator first, ForwardIterator last, T value);
*	
*	
*/


#include <iostream>	
#include <vector>	
#include <algo.h>

using namespace std;

int main(){
	
	// PRZYKLAD 1
	// wypelnianie wektora o pojemnosci 20, liczbami calkowitymi
	// zaczynajac od 0 wzwyz
	vector<int> v1(20);
	iota (v1.begin(), v1.end(), 0);
	// wpisanie danych
	copy(v1.begin(),v1.end(), ostream_iterator<int>(cout, " "));
  	cout << endl; 
	
	// PRZYKLAD 2
	// generowanie permutacji liczb calkowitych z przedzialu od 0 do 19
	vector<int> v2(20);
	iota(v2.begin(), v2.end(), 0);
	random_shuffle(v2.begin(),v2.end()); 
	// wypisanie danych
	copy(v2.begin(),v2.end(), ostream_iterator<int>(cout, " "));
  	cout << endl; 
	
	// PRZYKLAD 3
	// generowanie powtarzajacego sie, uporzadkowanego zbioru liczb(tu cyfr)
	// w tym przypadku: od 0 do 9, lacznie 50, czyli 5 takich grup
	vector<int> v3(50);
	vector<int>::iterator iter = v3.begin();
	int n =10;
	for(int i=0;i<v3.capacity()/n;++i)
		iota(iter+i*n, iter+(i+1)*n,0);
	// wypisanie danych
	copy(v3.begin(),v3.end(), ostream_iterator<int>(cout, " "));
  	cout << endl; 
	
	return 0;
}
